==> okta-sdk-api-20.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/ResourceSetResourcePostRequest.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * ResourceSetResourcePostRequest
 */
@JsonPropertyOrder({ ResourceSetResourcePostRequest.JSON_PROPERTY_RESOURCE_ORN_OR_URL })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class ResourceSetResourcePostRequest implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_RESOURCE_ORN_OR_URL = "resourceOrnOrUrl";
    private String resourceOrnOrUrl;

    public ResourceSetResourcePostRequest() {
    }

    public ResourceSetResourcePostRequest resourceOrnOrUrl(String resourceOrnOrUrl) {

        this.resourceOrnOrUrl = resourceOrnOrUrl;
        return this;
    }

    /**
     * Resource in ORN or REST API URL format
     *
     * @return resourceOrnOrUrl
     **/
    @javax.annotation.Nonnull
    @ApiModelProperty(required = true, value = "Resource in ORN or REST API URL format")
    @JsonProperty(JSON_PROPERTY_RESOURCE_ORN_OR_URL)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)

    public String getResourceOrnOrUrl() {
        return resourceOrnOrUrl;
    }

    @JsonProperty(JSON_PROPERTY_RESOURCE_ORN_OR_URL)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)
    public void setResourceOrnOrUrl(String resourceOrnOrUrl) {
        this.resourceOrnOrUrl = resourceOrnOrUrl;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ResourceSetResourcePostRequest resourceSetResourcePostRequest = (ResourceSetResourcePostRequest) o;
        return Objects.equals(this.resourceOrnOrUrl, resourceSetResourcePostRequest.resourceOrnOrUrl);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(resourceOrnOrUrl);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ResourceSetResourcePostRequest {\n");
        sb.append("    resourceOrnOrUrl: ").append(toIndentedString(resourceOrnOrUrl)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/ResourceSetResourcePostRequest.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * ResourceSetResourcePostRequest
 */
@JsonPropertyOrder({ ResourceSetResourcePostRequest.JSON_PROPERTY_RESOURCE_ORN_OR_URL })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class ResourceSetResourcePostRequest implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_RESOURCE_ORN_OR_URL = "resourceOrnOrUrl";
    private String resourceOrnOrUrl;

    public ResourceSetResourcePostRequest() {
    }

    public ResourceSetResourcePostRequest resourceOrnOrUrl(String resourceOrnOrUrl) {

        this.resourceOrnOrUrl = resourceOrnOrUrl;
        return this;
    }

    /**
     * Resource in ORN or REST API URL format
     *
     * @return resourceOrnOrUrl
     **/
    @javax.annotation.Nonnull
    @ApiModelProperty(required = true, value = "Resource in ORN or REST API URL format")
    @JsonProperty(JSON_PROPERTY_RESOURCE_ORN_OR_URL)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)

    public String getResourceOrnOrUrl() {
        return resourceOrnOrUrl;
    }

    @JsonProperty(JSON_PROPERTY_RESOURCE_ORN_OR_URL)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)
    public void setResourceOrnOrUrl(String resourceOrnOrUrl) {
        this.resourceOrnOrUrl = resourceOrnOrUrl;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ResourceSetResourcePostRequest resourceSetResourcePostRequest = (ResourceSetResourcePostRequest) o;
        return Objects.equals(this.resourceOrnOrUrl, resourceSetResourcePostRequest.resourceOrnOrUrl);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(resourceOrnOrUrl);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ResourceSetResourcePostRequest {\n");
        sb.append("    resourceOrnOrUrl: ").append(toIndentedString(resourceOrnOrUrl)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
